[−][src]Struct jpegxl_sys::JxlColorEncoding
Color encoding of the image as structured information.
Fields
color_space: JxlColorSpaceColor space of the image data.
white_point: JxlWhitePointBuilt-in white point. If this value is JXL_WHITE_POINT_CUSTOM, must use the numerical whitepoint values from white_point_xy.
white_point_xy: [f64; 2]Numerical whitepoint values in CIE xy space.
primaries: JxlPrimariesBuilt-in RGB primaries. If this value is JXL_PRIMARIES_CUSTOM, must use the numerical primaries values below. This field and the custom values below are unused and must be ignored if the color space is JXL_COLOR_SPACE_GRAY or JXL_COLOR_SPACE_XYB.
primaries_red_xy: [f64; 2]Numerical red primary values in CIE xy space.
primaries_green_xy: [f64; 2]Numerical green primary values in CIE xy space.
primaries_blue_xy: [f64; 2]Numerical blue primary values in CIE xy space.
transfer_function: JxlTransferFunctionTransfer function is have_gamma is 0
gamma: f64Gamma value used when transfer_function is JXL_TRANSFER_FUNCTION_GAMMA
rendering_intent: JxlRenderingIntentRendering intent defined for the color profile.