[−][src]Struct jpegxl_sys::JxlFrameHeader
The header of one displayed frame.
Fields
duration: u32How long to wait after rendering in ticks. The duration in seconds of a tick is given by tps_numerator and tps_denominator in JxlAnimationHeader.
timecode: u32SMPTE timecode of the current frame in form 0xHHMMSSFF, or 0. The bits are interpreted from most-significant to least-significant as hour, minute, second, and frame. If timecode is nonzero, it is strictly larger than that of a previous frame with nonzero duration. These values are only available if have_timecodes in JxlAnimationHeader is JXL_TRUE. This value is only used if have_timecodes in JxlAnimationHeader is JXL_TRUE.
name_length: u32Length of the frame name in bytes, or 0 if no name. Excludes null termination character.
is_last: c_intIndicates this is the last animation frame.